==> charlatan_0.4.0.tar.gz: charlatan/inst/doc/charlatan.R <==
## ----echo=FALSE---------------------------------------------------------------
knitr::opts_chunk$set(
  comment = "#>",
  collapse = TRUE,
  warning = FALSE,
  message = FALSE
)

## ----eval=FALSE---------------------------------------------------------------
#  install.packages("charlatan")

## ----eval=FALSE---------------------------------------------------------------
#  devtools::install_github("ropensci/charlatan")

## -----------------------------------------------------------------------------
library("charlatan")

## -----------------------------------------------------------------------------
x <- fraudster()
x$job()
x$name()
x$job()
x$color_name()

## -----------------------------------------------------------------------------
ch_job(locale = "en_US", n = 3)
ch_job(locale = "fr_FR", n = 3)
ch_job(locale = "hr_HR", n = 3)
ch_job(locale = "uk_UA", n = 3)
ch_job(locale = "zh_TW", n = 3)

## -----------------------------------------------------------------------------
ch_color_name(locale = "en_US", n = 3)
ch_color_name(locale = "uk_UA", n = 3)

## -----------------------------------------------------------------------------
ch_generate()

## -----------------------------------------------------------------------------
ch_generate('job', 'phone_number', n = 30)

## -----------------------------------------------------------------------------
ch_name()

## -----------------------------------------------------------------------------
ch_name(10)

## -----------------------------------------------------------------------------
ch_phone_number()

## -----------------------------------------------------------------------------
ch_phone_number(10)

## -----------------------------------------------------------------------------
ch_job()

## -----------------------------------------------------------------------------
ch_job(10)

## -----------------------------------------------------------------------------
ch_credit_card_provider()
ch_credit_card_provider(n = 4)

## -----------------------------------------------------------------------------
ch_credit_card_number()
ch_credit_card_number(n = 10)

## -----------------------------------------------------------------------------
ch_credit_card_security_code()
ch_credit_card_security_code(10)

## -----------------------------------------------------------------------------
testVector <- MissingDataProvider$new()

## -----------------------------------------------------------------------------
testVector$make_missing(x = ch_generate()$name) 

## -----------------------------------------------------------------------------
testVector$make_missing(x = ch_integer(10)) 

## -----------------------------------------------------------------------------
set.seed(123)
testVector$make_missing(x = sample(c(TRUE, FALSE), 10, replace = TRUE)) 

## -----------------------------------------------------------------------------
ch_name(50, messy = TRUE)

==> charlatan_0.6.1.tar.gz: charlatan/inst/doc/charlatan.R <==
## ----echo=FALSE---------------------------------------------------------------
knitr::opts_chunk$set(
  comment = "#>",
  collapse = TRUE,
  warning = FALSE,
  message = FALSE
)

## ----eval=FALSE---------------------------------------------------------------
#  install.packages("charlatan")

## ----eval=FALSE---------------------------------------------------------------
#  remotes::install_github("ropensci/charlatan")

## -----------------------------------------------------------------------------
library("charlatan")

## -----------------------------------------------------------------------------
x <- fraudster()
x$job()
x$name()
x$job()
x$color_name()

## -----------------------------------------------------------------------------
ch_job(locale = "en_US", n = 3)
ch_job(locale = "fr_FR", n = 3)
ch_job(locale = "hr_HR", n = 3)
ch_job(locale = "uk_UA", n = 3)
ch_job(locale = "zh_TW", n = 3)

## -----------------------------------------------------------------------------
ch_color_name(locale = "en_US", n = 3)
ch_color_name(locale = "uk_UA", n = 3)

## -----------------------------------------------------------------------------
ch_generate()

## -----------------------------------------------------------------------------
ch_generate("job", "phone_number", n = 30)

## -----------------------------------------------------------------------------
ch_name()

## -----------------------------------------------------------------------------
ch_name(10)

## -----------------------------------------------------------------------------
ch_phone_number()

## -----------------------------------------------------------------------------
ch_phone_number(10)

## -----------------------------------------------------------------------------
ch_job()

## -----------------------------------------------------------------------------
ch_job(10)

## -----------------------------------------------------------------------------
ch_currency(3)

## -----------------------------------------------------------------------------
ch_credit_card_provider()
ch_credit_card_provider(n = 4)

## -----------------------------------------------------------------------------
ch_credit_card_number()
ch_credit_card_number(n = 10)

## -----------------------------------------------------------------------------
ch_credit_card_security_code()
ch_credit_card_security_code(10)

## -----------------------------------------------------------------------------
testVector <- MissingDataProvider$new()

## -----------------------------------------------------------------------------
testVector$make_missing(x = ch_generate()$name)

## -----------------------------------------------------------------------------
testVector$make_missing(x = ch_integer(10))

## -----------------------------------------------------------------------------
set.seed(123)
testVector$make_missing(x = sample(c(TRUE, FALSE), 10, replace = TRUE))

## -----------------------------------------------------------------------------
ch_name(50, messy = TRUE)
